/********************************************************/
/*                                                      */
/* Copyright (c) 1993 by Automated Process Control      */
/*                       106 Business Park Drive        */
/*                       Jackson, Ms. 39213             */
/*                       Ph  (601) 956-2800             */
/*                       FAX (601) 956-9777             */
/*                                                      */
/* SPX 16 Bit Interface -- Library Routine              */
/*                                                      */
/*  File    : SPX_CTRL.C                                */
/*  Subject : Interface Control and Mapping Routine     */
/*  Version : 1.00                                      */
/*  Author  : Philip E. Foster                          */
/*  Date    : July 16, 1993                             */
/*                                                      */
/*  Code Compliance : Microsoft C 6.0a with ANSI C      */
/*                    language switch selected and      */
/*                    level 4 warnings                  */
/*                                                      */
/********************************************************/

#include "spx_c16.h"

/********************************************************/
/*                                                      */
/* if_map(ifbase, control, busy_tim, nbusy_tim)         */
/*  Parameters : ifbase is a "SPX_TYPE far *" to the    */
/*                      base address of the interface   */
/*                      array.                          */
/*               control is the value to write to the   */
/*                      CONTROL word.                   */
/*               busy_tim is the "timeout" value used   */
/*                      while waiting for the interface */
/*                      to indicate busy after writing  */
/*                      CONTROL                         */
/*               nbusy_tim is the "timeout" value used  */
/*                      while waiting for the interface */
/*                      to be NOT busy before writing   */
/*                      CONTROL                         */
/*  Returns    : SUCCESS if successful                  */
/*               TIMEOUT_NB if a timeout occured while  */
/*                      waiting for the interface to be */
/*                      NOT busy.                       */
/*               TIMEOUT_B if a timeout occured while   */
/*                      waiting for the interface to    */
/*                      become busy.                    */
/*                                                      */
/********************************************************/

int  if_map(SPX_TYPE far *ifbase, unsigned short control,
            unsigned long busy_tim, unsigned long nbusy_tim)
{
    while(if_statb(ifbase, __BUSY) && --nbusy_tim)  /* interface MUST be  */
        ;                                   /* NOT BUSY before continue   */

    if(!nbusy_tim)                          /* if "nbusy_tim" == 0        */
        return(TIMEOUT_NB);                 /*   we timed out.            */

    ifbase[CONTROL] = control;

    while(!if_statb(ifbase, __BUSY) && --busy_tim)  /* wait for interface */
        ;                                   /* to show BUSY so we know it */
                                            /* has accepted it            */
    if(!busy_tim)
        return(TIMEOUT_B);
    return(SUCCESS);
}
